package thermal;

import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Image;
import java.io.IOException;

import javax.swing.JPanel;

public class AutoResizeImage extends JPanel {

    private static final long serialVersionUID = -5440366595142150447L;
    private Image originalImage;
    private Image scaledImage;
    private int originalImageWidth;
    private int originalImageHeight;

    public AutoResizeImage() {
        super();
    }

    public AutoResizeImage(Image image) throws IOException {
        super();
        setIcon(image);
        setMinimumSize(new Dimension(1, 1));
    }

    public void paintComponent(Graphics g) {
        super.paintComponent(g);
        if (scaledImage != null) {
            scaleImage();
            int panelOffsetX = (this.getWidth() - scaledImage.getWidth(this)) / 2;
            int panelOffsetY = (this.getHeight() - scaledImage.getHeight(this)) / 2;
            g.drawImage(scaledImage, panelOffsetX, panelOffsetY, this);
        }
    }

    public void setIcon(Image image) {
        originalImage = image;
        originalImageWidth = originalImage.getWidth(this);
        originalImageHeight = originalImage.getHeight(this);
        setPreferredSize(new Dimension(originalImageWidth, originalImageHeight));
        setMinimumSize(new Dimension(originalImageWidth / 2, originalImageHeight / 2));
        scaleImage();
    }

    public void scaleImage() {
        if (originalImage != null) {
            int imageWidth = this.originalImageWidth;
            int imageHeight = this.originalImageHeight;
            int panelWidth = this.getWidth();
            int panelHeight = this.getHeight();

            if (panelWidth < imageWidth || panelHeight < imageHeight) {
                float percentScale = Math.min(((float) panelHeight / (float) panelWidth), ((float) imageHeight / (float) imageWidth));
                scaledImage = originalImage.getScaledInstance(Math.max((int) (imageWidth * percentScale), 1), Math.max((int) (imageHeight * percentScale), 1), Image.SCALE_DEFAULT);
            } else {
                scaledImage = originalImage;
            }
        }
    }
}